@@ -8,6 +8,7 @@ class BaseArgsParsing:
     TOKEN = 'token'
     IGNORE_CREATOR = 'ignore_creator'
     ALL_RESULT = 'all_result'
+    FILTER = 'filter'
 
     LIKE = "like"
     NOT = "not"
@@ -19,7 +20,7 @@ class BaseArgsParsing:
     ISNULL = 'isnull'
     OR = 'or'
 
-    RESERVED_FIELD = [PAGE, SIZE, PAGESIZE, SORT, TOKEN, IGNORE_CREATOR, ALL_RESULT]
+    RESERVED_FIELD = [PAGE, SIZE, PAGESIZE, SORT, TOKEN, IGNORE_CREATOR, ALL_RESULT, FILTER]
     SUFFIX_KEYWORD = [LIKE, NOT, IN, LT, GT, LTE, GTE, ISNULL, OR]
 
     def get_page_and_size(self, data, max_page=500, max_size=1000, max_total=10000):
